@@ -24,9 +24,9 @@ class PortfolioResponseData(BaseModel):
     content: PortfolioContent
     equity: float
     balance: float
-    positions: list = []
-    currencies: list = []
-    money: list = []
+    positions: list = []  # todo
+    currencies: list = []  # todo
+    money: list = []  # todo
 
 
 class PortfolioResponseModel(BaseModel):
